/*
 * Copyright (C) 2018 Richard Hughes <richard@hughsie.com>
 *
 * SPDX-License-Identifier: LGPL-2.1+
 */

#pragma once

#define __LIBXMLB_H_INSIDE__

#include <libxmlb/xb-builder.h>
#include <libxmlb/xb-builder-fixup.h>
#include <libxmlb/xb-builder-node.h>
#include <libxmlb/xb-builder-source.h>
#include <libxmlb/xb-builder-source-ctx.h>
#include <libxmlb/xb-machine.h>
#include <libxmlb/xb-node.h>
#include <libxmlb/xb-node-query.h>
#include <libxmlb/xb-node-silo.h>
#include <libxmlb/xb-opcode.h>
#include <libxmlb/xb-query-context.h>
#include <libxmlb/xb-silo-export.h>
#include <libxmlb/xb-silo.h>
#include <libxmlb/xb-silo-query.h>
#include <libxmlb/xb-stack.h>
#include <libxmlb/xb-string.h>
#include <libxmlb/xb-value-bindings.h>
#include <libxmlb/xb-version.h>

#undef __LIBXMLB_H_INSIDE__
